=======
History
=======

1.0.11 (2017-07-31)
------------------

* Add word_sent package

1.0.9 (2017-07-03)
------------------

* Add Corpus class
* Add Transformer classes
* Integrated with dictionary of Ho Ngoc Duc

1.0.1 (2017-03-02)
------------------

* Add travis-CI
* Auto build with PyPI

1.0.0 (2017-03-01)
------------------

* First release on PyPI.
* First release on Readthedocs
